@@ -15,6 +15,8 @@
 *
 */
 
+var current_test_case_name = "";
+
 passColor = "#cfffcf";
 failColor = "#ffcfcf";
 workingColor = "#DEE7EC";
@@ -103,8 +105,7 @@ function start() {
 
 function loadSuiteFrame() {
     var testAppFrame = document.getElementById('myiframe');
-    browserbot = createBrowserBot(testAppFrame);
-    selenium = new Selenium(browserbot);
+    selenium = Selenium.createForFrame(testAppFrame);
     registerCommandHandlers();
 
     //set the runInterval if there is a queryParameter for it
@@ -165,6 +166,7 @@ function onloadTestSuite() {
 
     } else {
         testLink = suiteTable.rows[currentTestRow+1].cells[0].getElementsByTagName("a")[0];
+	current_test_case_name = testLink;
         getTestFrame().src = testLink.href;
     }
 }
@@ -329,12 +331,13 @@ function runNextTest() {
         setCellColor(suiteTable.rows, currentTestRow, 0, workingColor);
 
         testLink = suiteTable.rows[currentTestRow].cells[0].getElementsByTagName("a")[0];
+	current_test_case_name = testLink;
         testLink.focus();
 
         var testFrame = getTestFrame();
         addLoadListener(testFrame, startTest);
 
-        browserbot.setIFrameLocation(testFrame, testLink.href);
+        selenium.browserbot.setIFrameLocation(testFrame, testLink.href);
     }
 }
 
@@ -488,7 +491,7 @@ function initialiseTestLoop() {
     testLoop.commandComplete = commandComplete;
     testLoop.commandError = commandError;
     testLoop.testComplete = testComplete;
-    testLoop.waitingForNext = function() {
+    testLoop.pause = function() {
         document.getElementById('continueTest').disabled = false;
     };
     return testLoop;
@@ -519,13 +522,8 @@ function scrollIntoView(element) {
         element.scrollIntoView(false);
         return;
     }
-
-    // For Konqueror, we have to create a remove an element.
-    var anchor = element.ownerDocument.createElement("a");
-    anchor.innerHTML = "!CURSOR!";
-    element.appendChild(anchor, element);
-//    anchor.focus();
-    element.removeChild(anchor);
+    // TODO: work out how to scroll browsers that don't support
+    // scrollIntoView (like Konqueror)
 }
 
 function commandStarted() {
@@ -591,7 +589,11 @@ function testComplete() {
 }
 
 function getCellText(rowNumber, columnNumber) {
-    return getText(inputTableRows[rowNumber].cells[columnNumber]);
+    var cell = inputTableRows[rowNumber].cells[columnNumber];
+    if (! cell.cachedText) {
+        cell.cachedText = getText(cell);
+    }
+    return cell.cachedText;
 }
 
 Selenium.prototype.doPause = function(waitTime) {
